@@ -89,3 +89,19 @@ class Conversation():
     def get_analytics(self):  
         return self.__conversation_api.get_analytics(self.__conversation_id, credentials=self.__credentials)
   
+    @validate_conversation_id
+    def put_members(self, members_id, parameters={}):
+        return self.__conversation_api.put_members(self.__conversation_id, members_id, parameters, credentials=self.__credentials)
+
+    @validate_conversation_id
+    def put_speakers_events(self, parameters={}):
+        return self.__conversation_api.put_speakers_events(self.__conversation_id, parameters, credentials=self.__credentials)
+
+    @validate_conversation_id
+    def delete_conversation(self):  
+        return self.__conversation_api.delete_conversation(self.__conversation_id, credentials=self.__credentials)
+  
+    @validate_conversation_id
+    def get_formatted_transcript(self, parameters={}):  
+        return self.__conversation_api.get_formatted_transcript(self.__conversation_id,parameters,credentials=self.__credentials)
+  
\ No newline at end of file
